@@ -15,8 +15,7 @@
 
 
 int
-compter_remplis (guchar **rempli, int width_i, int height_i)
-{
+compter_remplis (guchar **rempli, int width_i, int height_i) {
   int x_i, y_i;
   int somme = 0;
 
@@ -29,8 +28,7 @@ compter_remplis (guchar **rempli, int width_i, int height_i)
 }
 
 int *
-pixel_a_remplir (guchar **rempli, int width_i, int height_i, int *resultat)
-{
+pixel_a_remplir (guchar **rempli, int width_i, int height_i, int *resultat) {
   int x_i, y_i;
 
   for (y_i = 0; y_i < height_i; y_i++) {
@@ -46,8 +44,7 @@ pixel_a_remplir (guchar **rempli, int width_i, int height_i, int *resultat)
 }
 
 gint
-modulo (gint x, gint m)
-{
+modulo (gint x, gint m) {
   if (x >= m)   return x - m;
   else {
     if (x >= 0) return x;
